==> statpsych_1.3.0.tar.gz: statpsych/README.md <==

# statpsych: Statistical Methods for Psychologists

[![CRAN
status](https://www.r-pkg.org/badges/version/statpsych)](https://CRAN.R-project.org/package=statpsych)
![Download
count](https://cranlogs.r-pkg.org/badges/last-month/statpsych)

[statpsych](https://github.com/dgbonett/statpsych) implements confidence
interval and sample size methods that are especially useful in
psychological research. The methods can be applied in 1-group, 2-group,
paired-samples, and multiple-group designs and to a variety of
parameters including means, medians, proportions, slopes, standardized
mean differences, standardized linear contrasts of means, plus several
measures of correlation and association. The confidence intervals and
sample size functions are applicable to single parameters as well as
differences, ratios, and linear contrasts of parameters. The sample size
functions can be used to approximate the sample size needed to estimate
a parameter or function of parameters with desired confidence interval
precision or to perform a variety of hypothesis tests (directional
two-sided, equivalence, superiority, noninferiority) with desired power.
For details, see: <https://dgbonett.sites.ucsc.edu/>.

## Installation

You can install the currently-released version from CRAN with this R
command:

``` r
install.packages("stapsych")
```

Alternatively, you can install the latest development version from
GitHub with these R commands:

``` r
install.packages("devtools")
devtools::install_github("dgbonett/statpsych")
```

## Feedback, issues, and contributions

Submit feedback, suggestions, and bugs to github
[here](https://github.com/dgbonett/statpsych/issues/new).

==> statpsych_1.4.0.tar.gz: statpsych/README.md <==

# statpsych: Statistical Methods for Psychologists

[![CRAN
status](https://www.r-pkg.org/badges/version/statpsych)](https://CRAN.R-project.org/package=statpsych)
![Download
count](https://cranlogs.r-pkg.org/badges/last-month/statpsych)

[statpsych](https://github.com/dgbonett/statpsych) implements confidence
interval and sample size methods that are especially useful in
psychological research. The methods can be applied in 1-group, 2-group,
paired-samples, and multiple-group designs and to a variety of
parameters including means, medians, proportions, slopes, standardized
mean differences, standardized linear contrasts of means, plus several
measures of correlation and association. The confidence intervals and
sample size functions are applicable to single parameters as well as
differences, ratios, and linear contrasts of parameters. The sample size
functions can be used to approximate the sample size needed to estimate
a parameter or function of parameters with desired confidence interval
precision or to perform a variety of hypothesis tests (directional
two-sided, equivalence, superiority, noninferiority) with desired power.
For details, see: <https://dgbonett.sites.ucsc.edu/>.

## Installation

You can install the currently-released version from CRAN with this R
command:

``` r
install.packages("statpsych")
```

Alternatively, you can install the latest development version from
GitHub with these R commands:

``` r
install.packages("devtools")
devtools::install_github("dgbonett/statpsych")
```

## Feedback, issues, and contributions

Submit feedback, suggestions, and bugs to github
[here](https://github.com/dgbonett/statpsych/issues/new).
